Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(297)

Unified Diff: cc/playback/raster_source.h

Issue 2541183002: cc: Rename ImageDecodeController to ImageDecodeCache. (Closed)
Patch Set: rename: update Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/playback/image_hijack_canvas.cc ('k') | cc/playback/raster_source.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/playback/raster_source.h
diff --git a/cc/playback/raster_source.h b/cc/playback/raster_source.h
index 4fe6e5a373b8423a662921475ae878776e8c24ad..d040bcf9a1c8d9cb78340b55ce2cd523b4860f28 100644
--- a/cc/playback/raster_source.h
+++ b/cc/playback/raster_source.h
@@ -24,7 +24,7 @@ class ColorSpace;
namespace cc {
class DisplayItemList;
class DrawImage;
-class ImageDecodeController;
+class ImageDecodeCache;
class CC_EXPORT RasterSource : public base::RefCountedThreadSafe<RasterSource> {
public:
@@ -128,22 +128,19 @@ class CC_EXPORT RasterSource : public base::RefCountedThreadSafe<RasterSource> {
// Image decode controller should be set once. Its lifetime has to exceed that
// of the raster source, since the raster source will access it during raster.
- void set_image_decode_controller(
- ImageDecodeController* image_decode_controller) {
- DCHECK(image_decode_controller);
- image_decode_controller_ = image_decode_controller;
+ void set_image_decode_cache(ImageDecodeCache* image_decode_cache) {
+ DCHECK(image_decode_cache);
+ image_decode_cache_ = image_decode_cache;
}
// Returns the ImageDecodeController, currently only used by
// GpuRasterBufferProvider in order to create its own ImageHijackCanvas.
// Because of the MultiPictureDraw approach used by GPU raster, it does not
// integrate well with the use of the ImageHijackCanvas internal to this
// class. See gpu_raster_buffer_provider.cc for more information.
// TODO(crbug.com/628394): Redesign this to avoid exposing
- // ImageDecodeController from the raster source.
- ImageDecodeController* image_decode_controller() const {
- return image_decode_controller_;
- }
+ // ImageDecodeCache from the raster source.
+ ImageDecodeCache* image_decode_cache() const { return image_decode_cache_; }
protected:
friend class base::RefCountedThreadSafe<RasterSource>;
@@ -171,7 +168,7 @@ class CC_EXPORT RasterSource : public base::RefCountedThreadSafe<RasterSource> {
// In practice, this is only set once before raster begins, so it's ok with
// respect to threading.
- ImageDecodeController* image_decode_controller_;
+ ImageDecodeCache* image_decode_cache_;
private:
void RasterCommon(SkCanvas* canvas, SkPicture::AbortCallback* callback) const;
« no previous file with comments | « cc/playback/image_hijack_canvas.cc ('k') | cc/playback/raster_source.cc » ('j') | no next file with comments »
@@ -128,22 +128,19 @@ class CC_EXPORT RasterSource : public base::RefCountedThreadSafe<RasterSource> {
}
- // Returns the ImageDecodeController, currently only used by
+ // Returns the ImageDecodeCache, currently only used by
// GpuRasterBufferProvider in order to create its own ImageHijackCanvas.
// Because of the MultiPictureDraw approach used by GPU raster, it does not

Powered by Google App Engine
This is Rietveld 408576698